@@ -1,4 +1,3 @@
-from functools import wraps, partial
 from typing import Dict, List, Mapping, Any, get_type_hints
 import pickle
 import re
@@ -18,11 +17,7 @@ class PyotLazyObject:
     clas: Any
 
     def __init__(self, clas, obj, server_type, server):
-        try:
-            if clas.__origin__ is list:
-                self.clas = clas.__args__[0]
-        except Exception:
-            self.clas = clas
+        self.clas = clas
         self.server_map = [server_type, server]
         self.obj = obj
 
@@ -85,52 +80,41 @@ class PyotStaticObject:
         # META CLASS UNIQUE MUTABLE OBJECTS
         self._meta = self.Meta()
         self._meta.data = data
-        self._meta.types = typing_cache.get(self.__class__, partial(get_type_hints, self.__class__))
+        self._meta.types = typing_cache.get(self.__class__, self._get_types)
 
     def __getattribute__(self, name):
         try:
             attr = super().__getattribute__(name)
-            if type(attr) is PyotLazyObject:
+            if isinstance(attr, PyotLazyObject):
                 obj = attr()
                 setattr(self, name, obj)
                 return obj
             else:
                 return attr
-        except (KeyError, AttributeError):
-            raise AttributeError(f"'{self.__class__.__name__}' object has no attribute '{name}'")
+        except (KeyError, AttributeError) as e:
+            raise AttributeError(f"'{self.__class__.__name__}' object has no attribute '{name}'") from e
 
     def __getitem__(self, item):
         return self._meta.data[item]
 
-    def _rename(self, data):
-        # SNAKECASE > RENAME > REMOVE
-        new_data = {}
-        mapping = {}
-        for attr, val in data.items():
-            name = re.sub('(.)([A-Z][a-z]+)', r'\1_\2', attr)
-            newkey = re.sub('([a-z0-9])([A-Z])', r'\1_\2', name).lower()
-            if newkey in self._meta.removed:
-                continue
-            if newkey in self._meta.renamed:
-                newkey = self._meta.renamed[newkey]
-            mapping[attr] = newkey
-            new_data[newkey] = val
-
-        return new_data, mapping
-
-    def _normalize(self, data):
-        mapping = normalizer_cache.get(self.__class__, dict)
-        new_data = {}
-        for attr, val in data.items():
+    def _get_types(self):
+        types = get_type_hints(self.__class__)
+        for typ, clas in types.items():
             try:
-                new_data[mapping[attr]] = val
-            except KeyError:
-                new_data, new_mapping = self._rename(data)
-                mapping.update(new_mapping)
-                return new_data
-        for key in self._meta.removed:
-            new_data.pop(key, None)
-        return new_data
+                if clas.__origin__ is list:
+                    types[typ] = clas.__args__[0]
+            except Exception:
+                pass
+        return types
+
+    def _rename(self, key):
+        name = re.sub('(.)([A-Z][a-z]+)', r'\1_\2', key)
+        newkey = re.sub('([a-z0-9])([A-Z])', r'\1_\2', name).lower()
+        if newkey in self._meta.removed:
+            return None
+        if newkey in self._meta.renamed:
+            newkey = self._meta.renamed[newkey]
+        return newkey
 
     def _fill(self):
         # BIND SERVER > NORMALIZE > RAW > LAZY
@@ -140,21 +124,30 @@ class PyotStaticObject:
             setattr(self, server_type[0], server_type[1].lower())
         except AttributeError: pass
 
-        data_ = self._normalize(self._meta.data)
+        mapping = normalizer_cache.get(self.__class__, dict)
 
-        if self._meta.server_type in data_:
-            has_server = True
-        else:
-            has_server = False
+        for attr, renamed in self._meta.renamed.items():
+            if renamed != self._meta.server_type:
+                continue
+            server = self._meta.data.pop(attr, None)
+            if server:
+                setattr(self, self._meta.server_type, server.lower())
+            break
+
+        for key, val in self._meta.data.items():
+            try:
+                attr = mapping[key]
+            except KeyError:
+                attr = self._rename(key)
+                mapping[key] = attr
+            
+            if attr is None:
+                continue
 
-        for attr, val in data_.items():
             if attr in self._meta.raws:
                 setattr(self, attr, val)
             elif PyotLazyObject.need_lazy(val):
-                if has_server:
-                    server = data_[self._meta.server_type]
-                else:
-                    server = getattr(self, self._meta.server_type)
+                server = getattr(self, self._meta.server_type)
                 setattr(self, attr, PyotLazyObject(self._meta.types[attr], val, self._meta.server_type, server))
             elif attr == self._meta.server_type:
                 setattr(self, attr, val.lower())
@@ -204,6 +197,7 @@ class PyotStaticObject:
 class PyotContainerObject:
 
     class Meta:
+        # THIS META CLASS IS NOT INHERITED ON CORE, USED ONLY ON CONTAINER
         server_type: str = "locale"
         region_list = []
         platform_list = []
@@ -263,17 +257,30 @@ class PyotCoreObject(PyotStaticObject, PyotContainerObject):
         platform_list = []
         locale_list = []
 
-    async def get(self, sid: str = None, pipeline: str = None):
+    async def get(self, sid: str = None, pipeline: str = None, ptr_cache: PtrCache = None):
         '''Awaitable. Get this object from the pipeline.\n
         `sid` id identifying the session on the pipeline to reuse.\n
         `pipeline` key identifying the pipeline to execute against.\n
+        `ptr_cache` intercepts a PtrCache, usage details please refer to documentations.\n 
         '''
         self.set_pipeline(pipeline)
         token = await self.create_token()
+
+        if ptr_cache:
+            if not isinstance(ptr_cache, PtrCache):
+                raise TypeError(f"'ptr_cache' receives object of type 'PtrCache', got '{ptr_cache.__class__.__name__}'")
+            item = ptr_cache.get(token)
+            if item:
+                return item
+
         data = await self._meta.pipeline.get(token, sid)
         data = self._filter(data)
         self._meta.data = self._transform(data)
         self._fill()
+
+        if ptr_cache:
+            ptr_cache.set(token, self)
+
         return self
 
     async def post(self, sid: str = None, pipeline: str = None):
@@ -307,7 +314,7 @@ class PyotCoreObject(PyotStaticObject, PyotContainerObject):
         self._meta = self.Meta()
         self._meta.query = {}
         self._meta.data = {}
-        self._meta.types = typing_cache.get(self.__class__, partial(get_type_hints, self.__class__))
+        self._meta.types = typing_cache.get(self.__class__, self._get_types)
 
         self._set_server_type(kwargs)
         for name, val in kwargs.items():
@@ -334,8 +341,8 @@ class PyotCoreObject(PyotStaticObject, PyotContainerObject):
         if pipeline is None: return self
         try:
             self._meta.pipeline = pipelines[pipeline]
-        except KeyError:
-            raise RuntimeError(f"Pipeline '{pipeline}' does not exist, inactive or dead")
+        except KeyError as e:
+            raise RuntimeError(f"Pipeline '{pipeline}' does not exist, inactive or dead") from e
         return self
 
     def _parse_camel(self, kwargs) -> Dict:
@@ -349,7 +356,7 @@ class PyotCoreObject(PyotStaticObject, PyotContainerObject):
         self._get_server()
         self._refactor()
         self._validate()
-        if not hasattr(self._meta, "pipeline"): raise RuntimeError("Pyot pipeline for this model wasn't activated or lost")
+        if not hasattr(self._meta, "pipeline"): raise RuntimeError("Pyot pipeline for this model is not activated or lost")
         return PipelineToken(self._meta.pipeline.model, self._meta.server, self._meta.key, self._meta.load, self._meta.query)
 
     def _get_rule(self, search):
