@@ -3,7 +3,9 @@ from .champion import champion_id_by_key, champion_id_by_name, champion_key_by_i
 from .cdragon import cdragon_url, cdragon_sanitize, tft_url, tft_item_sanitize, tft_champ_sanitize
 from .objects import ptr_cache, frozen_generator, PtrCache, FrozenGenerator
 from .dicts import multi_defaultdict, redis_defaultdict, MultiDefaultDict, RedisDefaultDict
-from .common import snakecase, camelcase, shuffle_list, loop_run, thread_run, import_class, fast_copy, pytify, bytify
+from .common import snakecase, camelcase, shuffle_list, loop_run, thread_run, import_class, fast_copy, pytify, bytify, inherit_docstrings
+from .internal import silence_event_loop_closed
 from .locks import SealLock, RedisLock
 from .time import timeit, atimeit
 from .lor import batch_to_ccac
+
